# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

from gettext import gettext as _
from snack import Entry
from snack import FLAG_DISABLED
from snack import FLAGS_SET
from snack import FLAGS_RESET
from snack import Grid
from snack import GridForm
from snack import Label
from snack import SingleRadioButton
from snack import Textbox
from snack import TextboxReflowed
from wizpkg.wizardpanel import WizardPanel
from wizpkg.extendedwizardpanels import buildButtonBar


class MirrorConfigWizardPanel(WizardPanel):
    '''
    This class extends the base WizardPanel and uses
    one or more Entry as widget in its gridform
    User will be allowed to enter values into the entry
    fields.

             +-------------------------------+
             |     some title                |
             +-------------------------------+
             | Here are some instructions..  |
             | () http    () ftp             |
             | Host Name   _________________ |
             | Directory   _________________ |
             | Proxy       _________________ |
             |                               |
             | <back>   <next>   <cancel>    |
             +-------------------------------+
    '''

    def __init__(self, screen, name, paneltitle, msg, downloadproto, hostname,
                 repodir, proxy, index, panelaction):

        gf = GridForm(screen, paneltitle, 1, 4)
        tbprotocol = Textbox(60, 1,  _("Download Protocol:"), scroll=0)
        httprb = SingleRadioButton(_("http"), 0,
                                   1 if downloadproto == 'http' else 0)
        httpsrb = SingleRadioButton(_("https"), httprb,
                                    1 if downloadproto == 'https' else 0)
        ftprb = SingleRadioButton(_("ftp"), httprb,
                                  1 if downloadproto == 'ftp' else 0)
        rbgrid = Grid(1, 4)
        rbgrid.setField(tbprotocol, 0, 0, padding=(0, 0, 1, 0), anchorLeft=1)
        rbgrid.setField(httprb, 0, 1, padding=(1, 0, 0, 0), anchorLeft=1)
        rbgrid.setField(httpsrb, 0, 2, padding=(1, 0, 1, 0), anchorLeft=1)
        rbgrid.setField(ftprb, 0, 3, padding=(1, 0, 0, 0), anchorLeft=1)
        tb = TextboxReflowed(WizardPanel.WIDTH, msg)
        # Save entry in separate Grid and get a handle to it
        # to clear data when transitioning to previous panel
        g = Grid(2, 3)
        self.hostname = Entry(30, text=hostname, password=0)
        self.directory = Entry(30, text=repodir, password=0)
        self.proxy = Entry(30, text=proxy, password=0)
        g.setField(Label(_("Host Name ")), 0, 0, padding=(0, 0, 1, 0),
                   anchorLeft=1)
        g.setField(self.hostname, 1, 0, padding=(0, 0, 1, 0),
                   anchorLeft=1)
        g.setField(Label(_("Directory ")), 0, 1, padding=(0, 0, 1, 0),
                   anchorLeft=1)
        g.setField(self.directory, 1, 1, padding=(0, 0, 1, 0),
                   anchorLeft=1)
        g.setField(Label(_("Proxy ")), 0, 2, padding=(0, 0, 1, 0),
                   anchorLeft=1)
        g.setField(self.proxy, 1, 2, padding=(0, 0, 1, 0),
                   anchorLeft=1)

        gf.add(tb, 0, 0, padding=(0, 0, 0, 1), anchorLeft=1)
        gf.add(rbgrid, 0, 1, padding=(0, 0, 0, 1), anchorLeft=1)
        gf.add(g, 0, 2, anchorTop=0)
        bb = buildButtonBar(screen, index)
        gf.add(bb, 0, 3, padding=(0, 1, 0, 0), growx=1)
        self.ftprb = ftprb
        self.httprb = httprb
        self.httpsrb = httpsrb
        self.ftprb.setCallback(self.enableDisableProxy)
        self.enableDisableProxy()
        self.buttonBar = bb
        super(MirrorConfigWizardPanel, self).__init__(screen=screen,
                                                      name=name,
                                                      gridform=gf,
                                                      panelaction=panelaction)

    '''
    Method to be callsed to disable Proxy text entry
    when ftp is selected
    '''

    def enableDisableProxy(self):
        if self.ftprb.selected():
            s = FLAGS_SET
        else:
            s = FLAGS_RESET
        self.proxy.setFlags(FLAG_DISABLED, s)

    '''
    Obtain the entry list. This will be a list
    of tuple. Caller needs to iterate thru the
    list, then obtain values from the checkbox
    value.
    '''
    def getValues(self):
        entryList = []
        if self.httprb.selected():
            entryList.append("http")
        elif self.httpsrb.selected():
            entryList.append("https")
        else:
            entryList.append("ftp")
        entryList.append(None if not self.hostname.value()
                         else self.hostname.value())
        entryList.append(None if not self.directory.value()
                         else self.directory.value())
        entryList.append(None if not self.proxy.value()
                         else self.proxy.value())
        return entryList

    '''
    Returns whether or not FTP transfer is desired
    '''
    def ftpProtocolEnabled(self):
        return self.ftprb.selected()

    '''
    Performs step to determine the next action
    value returns is one of:
    0 = Cancel wizard
    -1 = Back to previous panel
    1 = Next panel
    '''
    def next(self):
        val = self.buttonBar.buttonPressed(self.result)
        if not self.result or val is None:
            return WizardPanel.NEXT
        return val

    '''
    This method validate user input on this wizard panel. Things checked:
    TBD: If we bind a method so that proxy entry is disable when ftp protocol
    is selected then validate() method is not needed. Else show error if
    user enter proxy information while protocol selected is FTP.
    '''
    def validate(self):
        return 0
