from snack import GridForm
from snack import TextboxReflowed
from snack import Listbox
from gettext import gettext as _
from wizpkg.wizardpanel import WizardPanel
from wizpkg.extendedwizardpanels import buildButtonBar


class NetworkDeviceWizardPanel(WizardPanel):
    '''
    This class extends the base WizardPanel and uses
    one or more Entry as widget in its gridform
    User will be allowed to select a single
    network interface

             +-------------------------------+
             |     some title                |
             +-------------------------------+
             | Here are some instructions..  |
             |                               |
             | o iface name | HW address     |
             | o iface name | HW address     |
             | ....                          |
             |                               |
             | <back>   <next>   <cancel>    |
             +-------------------------------+
    '''

    def __init__(self, screen, name, paneltitle, ethdev, index, panelaction):

        gf = GridForm(screen, paneltitle, 1, 3)
        msg = _("Select Network Interface.")
        tb = TextboxReflowed(WizardPanel.WIDTH, msg)

        height = len(ethdev.available_ports)
        scroll = 0
        # cap displayed interfaces to 8 at a time. display scrollbar
        if height > 8:
            height = 8
            scroll = 1

        self.lb = Listbox(height=height, scroll=scroll)

        for port in ethdev.available_ports:
            # port[0] = logicalname
            # port[1] = mac address
            # port[2] = location code
            self.lb.append(_("%s %s %s" % (port[0].ljust(ethdev.padding),
                                           port[1], port[2])), port[0])
            # set curtently selected iface
            if (port[0] == ethdev.selected_port):
                self.lb.setCurrent(port[0])

        self.buttonBar = buildButtonBar(screen, index)

        gf.add(tb, 0, 0, padding=(0, 0, 0, 1))
        gf.add(self.lb, 0, 1, padding=(0, 0, 0, 0))
        gf.add(self.buttonBar, 0, 2, padding=(0, 1, 0, 0), growx=1)

        super(NetworkDeviceWizardPanel, self).__init__(screen=screen,
                                                       name=name,
                                                       gridform=gf,
                                                       panelaction=panelaction)

    def getValues(self):

        entryList = []
        entryList.append(self.lb.current())
        return entryList
