# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

from gettext import gettext as _
from snack import Entry
from snack import Grid
from snack import GridForm
from snack import Label
from snack import TextboxReflowed
from wizpkg.wizardpanel import WizardPanel
from wizpkg.extendedwizardpanels import buildButtonBar
from procmem.virtprocinfo import VirtProcInfo
from procmem.virtprocinfo import BadVirtProcSettingsException
from procmem.meminfo import MemInfo
from procmem.meminfo import BadMemorySettingsException


class ProcMemoryWizardPanel(WizardPanel):
    '''
    This class extends the WizardPanel class and displays
    processor and memory information for user to select
    '''

    def __init__(self, screen, name, paneltitle, msgs, procinfo, meminfo,
                 index, panelaction):
        '''
        param: screen: the snack screen instance
        param: name: the name of the panel
        param: paneltitle: the displayed title of the panel
        param: msgs: the text messages with instructions or description
               of what the panel provides
        param: procinfo: an object containing information
               about processor values
        param: meminfo: an object containing information about memory
        param: index: the location to put the button bar
        param: panelaction: the callback function to call when the
               Next button is selected
        '''

        gf = GridForm(screen, paneltitle, 1, 5)
        tb = TextboxReflowed(WizardPanel.WIDTH, msgs[0])
        tbval = TextboxReflowed(WizardPanel.WIDTH, msgs[1])
        # Store this away so we can do proper
        # validation as we transition to the next panel
        self.procinfo = procinfo
        self.meminfo = meminfo
        g1 = Grid(1, 1)
        g1.setField(tbval, 0, 0, padding=(1, 0, 0, 0), anchorLeft=1)
        g2 = Grid(2, 2)
        g2.setField(Label(_("    Virtual Processor: ")), 0, 0,
                    padding=(1, 0, 0, 0), anchorLeft=1)
        self.procentry = Entry(10, text=procinfo.desiredvirtproc)
        g2.setField(self.procentry, 1, 0,
                    padding=(1, 0, 1, 0), anchorLeft=1)
        g2.setField(Label(_("    Memory (GB): ")), 0, 1,
                    padding=(1, 0, 0, 0), anchorLeft=1)
        self.mementry = Entry(10, text=meminfo.desiredmemory)
        g2.setField(self.mementry, 1, 1,
                    padding=(1, 0, 1, 0), anchorLeft=1)
        self.buttonBar = buildButtonBar(screen, index)
        gf.add(tb, 0, 0, padding=(0, 1, 0, 0), growx=1)
        gf.add(g1, 0, 1, padding=(0, 1, 0, 0), growx=1)
        gf.add(g2, 0, 2, padding=(0, 1, 0, 0), growx=1)
        gf.add(self.buttonBar, 0, 3, padding=(0, 1, 0, 0), growx=1)
        super(ProcMemoryWizardPanel, self).__init__(screen=screen,
                                                    name=name,
                                                    gridform=gf,
                                                    panelaction=panelaction)

    def validate(self):
        '''
        Validate entry entered by user
        '''
        procinfo = VirtProcInfo(self.procinfo.minvirtproc,
                                self.procinfo.maxvirtproc,
                                self.procentry.value())
        try:
            procinfo.validate()
        except BadVirtProcSettingsException as e:
            WizardPanel.showError(self.screen, str(e))
            return 1

        meminfo = MemInfo(self.meminfo.minmemory, self.meminfo.maxmemory,
                          self.mementry.value(), self.meminfo.lmbsize)
        try:
            meminfo.validate()
        except BadMemorySettingsException as e:
            WizardPanel.showError(self.screen, str(e))
            return 1
        return 0

    def getValues(self):
        '''
        Returns list of virtual processor and memory values
        '''
        entryList = []
        entryList.append(self.procentry.value())
        entryList.append(self.mementry.value())
        return entryList
