# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

from gettext import gettext as _


class BadProcUnitException(Exception):
    def __init__(self, msg):
        self.msg = msg

    def __str__(self):
        return self.msg


class ProcUnitInfo(object):
    '''
    This class holds processor unit information
    '''

    def __init__(self, minprocunit, maxprocunit, desiredprocunit):
        self._minprocunit = minprocunit
        self._maxprocunit = maxprocunit
        self._desiredprocunit = desiredprocunit

    @property
    def minprocunit(self):
        return self._minprocunit

    @minprocunit.setter
    def minprocunit(self, minprocunit):
        self._minprocunit = minprocunit

    @property
    def maxprocunit(self):
        return self._maxprocunit

    @maxprocunit.setter
    def maxprocunit(self, maxprocunit):
        self._maxprocunit = maxprocunit

    @property
    def desiredprocunit(self):
        return self._desiredprocunit

    @desiredprocunit.setter
    def desiredprocunit(self, desiredprocunit):
        self._desiredprocunit = desiredprocunit

    def validate(self):
        procunitdesired = 0
        minprocunit = 0
        maxprocunit = 0
        try:
            minprocunit = float(self._minprocunit)
        except ValueError:
            raise BadProcUnitException(_("Bad value "
                                         "for minimum proc unit"))
        try:
            maxprocunit = float(self._maxprocunit)
        except ValueError:
            raise BadProcUnitException(_("Bad value "
                                         "for maximum proc unit"))
        try:
            procunitdesired = float(self._desiredprocunit)
        except ValueError:
            raise BadProcUnitException(_("Bad value "
                                         "for desired proc unit"))

        if not (procunitdesired >= minprocunit and
                procunitdesired <= maxprocunit):
            raise BadProcUnitException(_("Desired proc unit value "
                                         "is not in the range of %s "
                                         "and %s" %
                                         (self._minprocunit,
                                          self._maxprocunit)))
