# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

from gettext import gettext as _
from wizpkg.extendedwizardpanels import RadioButtonDescriptionWizardPanel
from wizpkg.extendedwizardpanels import MissingTupleException
from wizpkg.extendedwizardpanels import AcknowledgementWizardPanel
from wizpkg.wizardpanel import WizardPanel
from wizpkg.progressbar import CommandProgressWindow
from wizpkg.progressbar import ExecWithProgress
import os


def exec_shell(screen):
    screen.suspend()
    msg = _("Type 'exit' to return to wizard")
    os.system("/usr/bin/clear;"
              " echo "+msg+";ENV=/opt/ibm/pvm-install/bin/envsetup /bin/sh")
    screen.resume()


def show_main(screen):
    '''
    Displays the main recovery Displays
    The options are in the panelButtonTuple and the corresponding description
    message is in panelDescriptionTuple.
    '''
    panelName = _("Recovery")
    panelTitle = _("PowerVM NovaLink System Recovery Options:")
    panelMessage = _("Select one the following options")

    tuplemgs1 = _("Reset system")
    tuplemsg2 = _("Access Shell")
    tuplemsg1desc = _("Power off all partitions, clear NVRAM and reboot "
                      "the system. All partition configuration will be lost.")

    tuplemsg2desc = _("Access the shell to run commands. For example, the "
                      "mkvterm command can be used to gain console access "
                      "to the VIOS server(s) if available.")

    panelButtonTuple = [(tuplemgs1, 0, 1), (tuplemsg2, 1, 0)]
    panelDescriptionTuple = [(tuplemsg1desc, 1), (tuplemsg2desc, 0)]
    try:
        mainPanel = RadioButtonDescriptionWizardPanel(screen, panelName,
                                                      panelTitle, panelMessage,
                                                      panelButtonTuple,
                                                      panelDescriptionTuple,
                                                      WizardPanel.MIDDLE,
                                                      panelaction=None)
        mainPanel.run()
    except MissingTupleException:
        WizardPanel.showError(screen, _("An error has occured."))
    return (mainPanel.next(), mainPanel.getValues())


def show_reset_system(screen):
    '''
    Displays the corresponding panels to Reset System to greenfield.
    '''
    panelName = _("Reset System")
    panelMessage = _("Resetting the system will power off all partitions,"
                     " clear NVRAM and reboot the system.\n"
                     "Do you want to continue?")
    resetPanel = AcknowledgementWizardPanel(screen, panelName,
                                            panelMessage, panelaction=None)
    resetPanel.run()
    nextpanel = resetPanel.next()
    if nextpanel == WizardPanel.NEXT:
        title = _("Reset System")
        text = _("Power off partitions and clear NVRAM...")
        w = CommandProgressWindow(screen, title, text, 100, 10, update=True)
        rc = ExecWithProgress.runcmd("/opt/ibm/pvm-install/bin/resetsystem",
                                     [], screen, stdout="/tmp/exec.out",
                                     stderr="/tmp/exec.err", pBar=w)
        if rc != 0:
            WizardPanel.showError(screen, _("An error has occured while"
                                            " resetting the system."))
        else:
            # By suspending the screen and run shutdown here we avoid leaving
            # the terminal screen in a bad state
            screen.suspend()
            os.system("/usr/bin/clear;shutdown -r")


def run_recovery_wizard(screen):
    '''
    The Recovery wizard Main function.
    '''
    while True:
        (nextpanel, selectedValue) = show_main(screen)
        if nextpanel == WizardPanel.BACK:
            return WizardPanel.INIT
        if nextpanel == WizardPanel.CANCEL:
            return WizardPanel.EXIT
        if nextpanel == WizardPanel.NEXT:
            if selectedValue == 0:
                show_reset_system(screen)
            elif selectedValue == 1:
                exec_shell(screen)
    return WizardPanel.INIT
