#!/usr/bin/python

import subprocess
import argparse
import paramiko
import sys

LOCAL_PATH = "/tmp/restore-local"


def rstprofdata_cmd():
    print("Restoring backup data...")
    subprocess.check_output("/usr/bin/rstprofdata -l 1 -f " +
                            LOCAL_PATH, shell=True)


def wget_backup_files(args):
    print("Getting backup file from : " + args.f)
    subprocess.check_output("/usr/bin/wget " + str(args.f) + " -O " +
                            LOCAL_PATH, shell=True)
    rstprofdata_cmd()


def ssh_get_backup_files(args):

    try:
        print("Connecting to: " + args.host + " as user: " + str(args.u))
        ssh = paramiko.SSHClient()

        ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
        ssh.connect(args.host, username=args.u, password=args.p)
        print("Downloading file...")
        sftp = ssh.open_sftp()
        sftp.get(args.f, LOCAL_PATH)
        sftp.close()
        ssh.close()
    except OSError as e:
        print(str(e))
    except:
        print("File transfer failed: "), sys.exc_info()[0]

    rstprofdata_cmd()


def create_parser():
    parser = argparse.ArgumentParser(prog="restore")
    subparsers = parser.add_subparsers(dest='scp,wget',
                                       help='sub-command help')

    parser_scp = subparsers.add_parser("scp", help=("use scp"))
    parser_scp.set_defaults(func=ssh_get_backup_files)
    # Target system name
    parser_scp.add_argument("-host",
                            required=True,
                            help=("host name"))

    # User name
    parser_scp.add_argument("-u",
                            required=True,
                            help=("user name"))

    # Password
    parser_scp.add_argument("-p",
                            required=True,
                            help=("password"))

    # remote file path
    parser_scp.add_argument("-f",
                            help=("remote file path"))

    parser_wget = subparsers.add_parser("wget", help=("use wget"))
    parser_wget.set_defaults(func=wget_backup_files)
    # full path to file
    parser_wget.add_argument("-f",
                             help=("full file path"))

    return parser


def main():
    parser = create_parser()
    args = parser.parse_args()
    args.func(args)

if __name__ == "__main__":
    main()
