# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

import ast
from gettext import gettext as _
from snack import Grid
from snack import GridForm
from snack import Listbox
from snack import TextboxReflowed
from pvmconfigdata import PVMConfigData as pcd
from wizpkg.wizardpanel import WizardPanel


class SummaryPanel(WizardPanel):
    '''
    This class extends the base WizardPanel and uses
    one or more Entry as widget in its gridform
    It presents all the data users have entered from all the
    previous wizard panel.
             +---------------------------------------------------+
             |     some title                                    |
             +---------------------------------------------------+
             | Here are some instructions..                      |
             | <button to edit configuration file>               |
             |     information ...                               |
             |     NTP Server: some-ntp-server                   |
             |                                                   |
             |                                                   |
             |                                                   |
             | <back>          <finish>        <cancel>          |
             +---------------------------------------------------+
    '''

    def __init__(self, screen, name, paneltitle, msg, cfgdata, buttonbar,
                 show_vios, index, panelaction):

        gf = GridForm(screen, paneltitle, 1, 3)
        tb = TextboxReflowed(WizardPanel.WIDTH, msg)
        g = Grid(1, 1)
        self.summarylb = self.get_summary(cfgdata, show_vios)
        g.setField(self.summarylb, 0, 0, padding=(0, 1, 0, 0), anchorLeft=1)
        gf.add(tb, 0, 0, anchorLeft=1, growy=1)
        gf.add(g, 0, 1, anchorLeft=1)
        gf.add(buttonbar, 0, 2, padding=(0, 1, 0, 0), growx=1)
        self.buttonBar = buttonbar
        super(SummaryPanel, self).__init__(screen=screen,
                                           name=name, gridform=gf,
                                           panelaction=panelaction)

    def get_summary(self, cfgdata, show_vios):
        '''
        Obtain summary data and build a Listbox
        A listbox is used since visually there is a cursor showing current
        item as opposed to merely use a textbox.
        '''

        padding1 = "    "
        padding2 = "        "
        newline = "\n"
        summary = Listbox(8, width=WizardPanel.WIDTH + 4, scroll=1)
        summary.append(padding1 + _("Time zone: ") +
                       (cfgdata.get_attribute
                        (pcd.GENERAL_SETTINGS_SECTION, pcd.TIMEZONE)) +
                       newline, 'None')
        ntpenabled = cfgdata.get_attribute(pcd.GENERAL_SETTINGS_SECTION,
                                           pcd.NTPENABLED)
        if ntpenabled:
            summary.append(padding1 + _("NTP Server: ") +
                           (cfgdata.get_attribute
                            (pcd.GENERAL_SETTINGS_SECTION, pcd.NTPSERVER)) +
                           newline, 'None')
        summary.append(padding1 + _("NovaLink partition:") + newline, 'None')
        summary.append(padding2 + _("User Name: ") +
                       (cfgdata.get_attribute
                        (pcd.CREDENTIALS_SECTION, pcd.USERNAME)) +
                       newline, 'None')
        dhcpip = cfgdata.get_attribute(pcd.NETWORK_SETTINGS_SECTION,
                                       pcd.DHCPIP)
        usedhcp = True
        if dhcpip and dhcpip != 'DISABLED':
            summary.append(padding2 + _("IP Address assignment: Dynamic Host "
                                        "Configuration protcol") + newline,
                           'None')
        else:
            usedhcp = False
            summary.append(padding2 + _("IP Address assignment: Static") +
                           newline, 'None')

        interface = cfgdata.get_attribute(pcd.PVM_CONFIG_SECTION,
                                          pcd.TARGET_NETWORK_DEVICE)
        if interface != "":
            summary.append(padding1 + padding2 + _("Interface name: ") +
                           interface + newline, 'None')

        # Common network information regardless of protocol used
        summary.append(padding1 + padding2 + _("Host name: ") +
                       cfgdata.get_attribute(pcd.NETWORK_SETTINGS_SECTION,
                                             pcd.HOSTNAME) + newline, 'None')
        summary.append(padding1 + padding2 + _("Domain name: ") +
                       cfgdata.get_attribute(pcd.NETWORK_SETTINGS_SECTION,
                                             pcd.DOMAIN) + newline, 'None')
        if not usedhcp:
            summary.append(padding1 + padding2 + _("IP address: ") +
                           cfgdata.get_attribute(pcd.NETWORK_SETTINGS_SECTION,
                                                 pcd.IPADDR) + newline,
                           'None')
            summary.append(padding1+padding2+_("Network mask: ") +
                           cfgdata.get_attribute(pcd.NETWORK_SETTINGS_SECTION,
                                                 pcd.NETMASK) + newline,
                           'None')
            summary.append(padding1 + padding2 + _("Gateway: ") +
                           cfgdata.get_attribute(pcd.NETWORK_SETTINGS_SECTION,
                                                 pcd.GATEWAY) + newline,
                           'None')
        summary.append(padding1 + padding2 + _("DNS: ") +
                       cfgdata.get_attribute(pcd.NETWORK_SETTINGS_SECTION,
                                             pcd.DNS1) + " " +
                       cfgdata.get_attribute(pcd.NETWORK_SETTINGS_SECTION,
                                             pcd.DNS2) + " " +
                       cfgdata.get_attribute(pcd.NETWORK_SETTINGS_SECTION,
                                             pcd.DNS3) + newline, 'None')

        if show_vios:
            summary.append(padding1 + _("VIOS Processor and Memory:") +
                           newline, 'None')
            summary.append(padding2 +
                           _("Minimum virtual processor: ") +
                           cfgdata.get_attribute(pcd.VIOS_CONFIG_SECTION,
                                                 pcd.VIRTUALPROCMIN) + newline,
                           'None')
            summary.append(padding2 +
                           _("Maximum virtual processor: ") +
                           cfgdata.get_attribute(pcd.VIOS_CONFIG_SECTION,
                                                 pcd.VIRTUALPROCMAX) + newline,
                           'None')
            summary.append(padding2 +
                           _("Desired virtual processor: ") +
                           cfgdata.get_attribute(pcd.VIOS_CONFIG_SECTION,
                                                 pcd.VIRTUALPROCDESIRED) +
                           newline, 'None')
            summary.append(padding2 +
                           _("Minimum memory: ") +
                           cfgdata.get_attribute(pcd.VIOS_CONFIG_SECTION,
                                                 pcd.MINMEMORY) + _("(GB)") +
                           newline, 'None')
            summary.append(padding2 +
                           _("Maximum memory: ") +
                           cfgdata.get_attribute(pcd.VIOS_CONFIG_SECTION,
                                                 pcd.MAXMEMORY) + _("(GB)") +
                           newline, 'None')
            summary.append(padding2 +
                           _("Desired memory: ") +
                           cfgdata.get_attribute(pcd.VIOS_CONFIG_SECTION,
                                                 pcd.DESIREDMEMORY) +
                           _("(GB)") + newline, 'None')

            # Network information for VIOS1
            summary.append(padding1 + _("VIOS 1 Network Configuration:") +
                           newline, 'None')

            dhcpip = cfgdata.get_attribute(pcd.VIOS1_NETW_SETTINGS_SECTION,
                                           pcd.DHCPIP)
            usedhcp = True
            if dhcpip and dhcpip != 'DISABLED':
                summary.append(padding2 +
                               _("IP Address assignment: Dynamic Host "
                                 "Configuration protcol") + newline,
                               'None')
            else:
                usedhcp = False
                summary.append(padding2 + _("IP Address assignment: Static") +
                               newline, 'None')
            # Common network information regardless of protocol used
            hn = cfgdata.get_attribute(pcd.VIOS1_NETW_SETTINGS_SECTION,
                                       pcd.HOSTNAME)
            dn = cfgdata.get_attribute(pcd.VIOS1_NETW_SETTINGS_SECTION,
                                       pcd.DOMAIN)
            summary.append(padding1 + padding2 + _("Host name: ") +
                           hn + newline, 'None')
            summary.append(padding1 + padding2 + _("Domain name: ") +
                           dn + newline, 'None')
            if not usedhcp:
                ipaddr = cfgdata.get_attribute(pcd.VIOS1_NETW_SETTINGS_SECTION,
                                               pcd.IPADDR)
                nwmask = cfgdata.get_attribute(pcd.VIOS1_NETW_SETTINGS_SECTION,
                                               pcd.NETMASK)
                gw = cfgdata.get_attribute(pcd.VIOS1_NETW_SETTINGS_SECTION,
                                           pcd.GATEWAY)
                dns1 = cfgdata.get_attribute(pcd.VIOS1_NETW_SETTINGS_SECTION,
                                             pcd.DNS1)
                dns2 = cfgdata.get_attribute(pcd.VIOS1_NETW_SETTINGS_SECTION,
                                             pcd.DNS2)
                dns3 = cfgdata.get_attribute(pcd.VIOS1_NETW_SETTINGS_SECTION,
                                             pcd.DNS3)
                summary.append(padding1 + padding2 + _("IP address: ") +
                               ipaddr + newline, 'None')
                summary.append(padding1 + padding2+_("Network mask: ") +
                               nwmask + newline, 'None')
                summary.append(padding1 + padding2 + _("Gateway: ") +
                               gw + newline, 'None')
                summary.append(padding1 + padding2 + _("DNS: ") +
                               dns1 + " " + dns2 + " " + dns3 +
                               newline, 'None')

            sdn_enabled = cfgdata.get_attribute_notstr(pcd.SDN_CONFIG_SECTION,
                                                       pcd.SDN_ENABLED)
            if sdn_enabled:
                summary.append(padding1 + _("Enable SDN: ") +
                               str(sdn_enabled) + newline, 'None')

            # Determine number of VIOS to show whether or not I/O Redundancy
            # was selected.
            ioredundant = cfgdata.get_attribute(pcd.PVM_CONFIG_SECTION,
                                                pcd.IOREDUNDANCY)
            ioredundantStr = _("False")
            if ioredundant is True:
                ioredundantStr = _("True")
            summary.append(padding1 + _("I/O Redundancy: ") +
                           ioredundantStr + newline, 'None')
            if ast.literal_eval(str(ioredundant)):
                # Network information for VIOS2
                summary.append(padding1 + _("VIOS 2 Network Configuration:") +
                               newline, 'None')
                dhcpip = cfgdata.get_attribute(pcd.VIOS2_NETW_SETTINGS_SECTION,
                                               pcd.DHCPIP)
                usedhcp = True
                if dhcpip and dhcpip != 'DISABLED':
                    summary.append(padding2 +
                                   _("IP Address assignment: Dynamic Host "
                                     "Configuration protcol") + newline,
                                   'None')
                else:
                    usedhcp = False
                    summary.append(padding2 +
                                   _("IP Address assignment: Static") +
                                   newline, 'None')
                # Common network information regardless of protocol used
                hn = cfgdata.get_attribute(pcd.VIOS2_NETW_SETTINGS_SECTION,
                                           pcd.HOSTNAME)
                dn = cfgdata.get_attribute(pcd.VIOS2_NETW_SETTINGS_SECTION,
                                           pcd.DOMAIN)
                summary.append(padding1 + padding2 + _("Host name: ") +
                               hn + newline, 'None')
                summary.append(padding1 + padding2 + _("Domain name: ") +
                               dn + newline, 'None')
                if not usedhcp:
                    ipaddr = cfgdata.get_attribute(
                        pcd.VIOS2_NETW_SETTINGS_SECTION, pcd.IPADDR)
                    nwmask = cfgdata.get_attribute(
                        pcd.VIOS2_NETW_SETTINGS_SECTION, pcd.NETMASK)
                    gw = cfgdata.get_attribute(pcd.VIOS2_NETW_SETTINGS_SECTION,
                                               pcd.GATEWAY)
                    dns1 = cfgdata.get_attribute(
                        pcd.VIOS2_NETW_SETTINGS_SECTION, pcd.DNS1)
                    dns2 = cfgdata.get_attribute(
                        pcd.VIOS2_NETW_SETTINGS_SECTION, pcd.DNS2)
                    dns3 = cfgdata.get_attribute(
                        pcd.VIOS2_NETW_SETTINGS_SECTION, pcd.DNS3)
                    summary.append(padding1 + padding2 + _("IP address: ") +
                                   ipaddr + newline, 'None')
                    summary.append(padding1 + padding2+_("Network mask: ") +
                                   nwmask + newline, 'None')
                    summary.append(padding1 + padding2 + _("Gateway: ") +
                                   gw + newline, 'None')
                    summary.append(padding1 + padding2 + _("DNS: ") +
                                   dns1 + " " + dns2 + " " + dns3 +
                                   newline, 'None')

            # Display IO adapter information for VIOS1, VIOS2, SDN1,
            # and SDN2 (when available).
            ioinfo_arr = self.get_ioadapter_info("VIOS1", cfgdata)
            for ioinfoline in ioinfo_arr:
                summary.append(ioinfoline, 'None')
            if ast.literal_eval(str(ioredundant)):
                ioinfo_arr = self.get_ioadapter_info("VIOS2", cfgdata)
                for ioinfoline in ioinfo_arr:
                    summary.append(ioinfoline, 'None')
            if (sdn_enabled):
                ioinfo_arr = self.get_ioadapter_info("SDN1", cfgdata)
                for ioinfoline in ioinfo_arr:
                    summary.append(ioinfoline, 'None')

        selTargetDisks = cfgdata.get_attribute(pcd.PVM_CONFIG_SECTION,
                                               pcd.TARGET_DISK_INSTALL)

        if selTargetDisks:
            summary.append(padding2 + _("Installation Disk(s): ") +
                           selTargetDisks + newline, 'None')

        return summary

    def get_ioadapter_info(self, entityname, cfgdata):
        ioinfo_arr = []
        cfg_section = ''
        entity_label = ''
        padding1 = "    "
        padding2 = "        "
        newline = "\n"
        if (entityname == "SDN1"):
            cfg_section = pcd.SDN1_PHYS_IO_CONFIG_SECTION
            entity_label = _("SDN 1 Physical Adapters:")
        elif (entityname == "SDN2"):
            cfg_section = pcd.SDN2_PHYS_IO_CONFIG_SECTION
            entity_label = _("SDN 2 Physical Adapters:")
        elif (entityname == "VIOS1"):
            cfg_section = pcd.VIOS1_PHYS_IO_CONFIG_SECTION
            entity_label = _("VIOS 1 Physical Adapters:")
        elif (entityname == "VIOS2"):
            cfg_section = pcd.VIOS2_PHYS_IO_CONFIG_SECTION
            entity_label = _("VIOS 2 Physical Adapters:")

        pio = cfgdata.get_attribute(cfg_section, pcd.INFO)
        if (pio):
            ioinfo = ast.literal_eval(str(pio))
            ioinfo_arr.append(padding1 + _(entity_label) + newline)
            for k in ioinfo:
                sval = k + ' ' + ioinfo[k]
                ioinfo_arr.append(padding2 + sval)

        return (ioinfo_arr)
