# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

import ast
from snack import Grid
from snack import GridForm
from snack import SingleRadioButton
from snack import TextboxReflowed
from gettext import gettext as _
from wizpkg.wizardpanel import WizardPanel


class IORedundantWizardPanel(WizardPanel):
    '''
    This class extends the base WizardPanel and uses
    one or more RadioButton as widget in its gridform.
             +-----------------------------------------+
             |     some title                          |
             +-----------------------------------------+
             | Here are some instructions..            |
             |                                         |
             | [ ] Some text                           |
             | [ ] Some other text                     |
             | ...                                     |
             |                                         |
             | <back>  <next>  <view sample> <cancel>  |
             +-----------------------------------------+
    '''
    REDUNDANT = 'REDUNDANT'
    NOREDUNDANT = 'NOREDUNDANT'

    def __init__(self, screen, name, paneltitle, msg,
                 redundant, bb, position, panelaction):
        '''
        Init method
        :param screen: SnackScreen instance
        :param name: Name of the panel
        :param paneltitle: Panel title displayed to user
        :param msg: Message displayed to user as instructions
        :param redundant: Redundant IO or not
        :param bb: Button bar
        :param position: Panel position in wizard
        :param panelaction: Function to called when user transition out
        '''
        gf = GridForm(screen, paneltitle, 1, 3)
        tb = TextboxReflowed(WizardPanel.WIDTH, msg)

        io_red = True if redundant == '' else ast.literal_eval(str(redundant))
        redundant_button_msg = _("Choose to create I/O redundancy.")
        redundantmsg = _("This will create a dual Virtual I/O server "
                         "configuration.")
        noredundant_button_msg = _("Choose no I/O redundancy.")
        noredundantmsg = _("This will create a single Virtual I/O server.")
        self.redundantrb = SingleRadioButton(redundant_button_msg, 0,
                                             1 if io_red else 0)
        self.noredundantrb = SingleRadioButton(noredundant_button_msg,
                                               self.redundantrb,
                                               0 if io_red else 1)
        g = Grid(1, 4)
        g.setField(self.redundantrb, 0, 0, padding=(0, 0, 1, 0), anchorLeft=1)
        g.setField(TextboxReflowed(WizardPanel.WIDTH, redundantmsg), 0, 1,
                   padding=(4, 0, 0, 1), anchorLeft=1)
        g.setField(self.noredundantrb, 0, 2, padding=(0, 0, 1, 0),
                   anchorLeft=1)
        g.setField(TextboxReflowed(WizardPanel.WIDTH, noredundantmsg), 0, 3,
                   padding=(4, 0, 0, 1), anchorLeft=1)
        gf.add(tb, 0, 0, padding=(0, 0, 0, 1), anchorTop=0)
        gf.add(g, 0, 1, growy=1, anchorTop=0)
        self.buttonBar = bb
        gf.add(bb, 0, 2, padding=(0, 1, 0, 0), growx=1)
        super(IORedundantWizardPanel, self).__init__(screen=screen,
                                                     name=name, gridform=gf,
                                                     panelaction=panelaction)

    def getValues(self):
        '''
        Obtain values selected
        '''
        if self.redundantrb.selected():
            return IORedundantWizardPanel.REDUNDANT
        elif self.noredundantrb.selected():
            return IORedundantWizardPanel.NOREDUNDANT


class IORedundantSamplePanel():
    '''
    A simple panel that read an ASCII art text file then displays
    it. Only 1 button shown
    '''

    def __init__(self, screen, name, paneltitle, sfile, bb):
        '''
        Init method
        :param screen: SnackScreen instance
        :param name: Name of the panel
        :param paneltitle: Panel title displayed to user
        :param sfile: File containing the ASCII art to display
        :param bb: Button
        '''
        gf = GridForm(screen, paneltitle, 1, 2)
        with open(sfile, "r") as asciiartfile:
            msg = asciiartfile.read()

        tb = TextboxReflowed(WizardPanel.WIDTH, msg)
        gf.add(tb, 0, 0, padding=(0, 0, 0, 1), anchorTop=0)
        gf.add(bb, 0, 1, padding=(0, 1, 0, 0), growx=1)
        gf.run()
        screen.popWindow(True)
